==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/ru/download30.php <==
<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2012 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!-- Insert actual page content below -->

<h3 class="top">Установка из исходных текстов</h3>

dvdisaster использует обычный механизм: <tt>./configure; make; make install</tt>,- 
для установки из исходных текстов. Более подробно смотрите в файле <tt>INSTALL</tt> в
дистрибутиве исходных текстов.
<pre> </pre>

<a name="mac"></a>
<h3>Установка двоичных файлов для Mac OS X</h3>
В ZIP-архиве содержится пакет приложения, сделанный для Mac OS X 10.5
на процессорах x86. Распакуйте архив в нужное место и нажмите кнопку мыши на
"dvdisaster.app" для запуска программы.
dvdisaster может работать под Mac OS X 10.4 и на процессорах PowerPC;
однако в таком случае вам потребуется собрать свою собственную версию из
исходных текстов.<p>

<i>Имейте в виду, что графический интерфейс пользователя еще немного 
шероховат.</i> Набор средств для построения интерфейсов GTK+ еще находится в ранней
стадии развития для Mac OS X. Интерфейс пользователя может выглядеть неаккуратно или
замирать на небольшое время. В графическом выводе могут быть сбои.
Вы можете минимизировать эти эффекты, не трогая окно dvdisaster,
когда что-либо происходит в окне. В особенности избегайте изменения размеров окна
и сворачивания его.<p>

Во время цикла разработки версии 0.73 могут быть реализованы некоторые обходные пути
для этих эффектов; в противном случает планируется подождать улучшенной версии
GTK+.<p>

Не планируется разработка версии dvdisaster, независимой от GTK+,
поскольку это означает полное переписывание программы для Quartz.
Между прочим, аналогичные соображения относятся к версии для Windows ;-)
<pre> </pre>

<a name="win"> </a>
<h3>Установка двоичных версий для Windows</h3>

Для установки Windows-версии, запускайте на выполнение двоичный файл
(например,  <?php echo ${pkgname}?>-setup.exe) и следуйте диалогу в процессе установки. <p>

<b>Предупреждение:</b> dvdisaster НЕ устанавливается путем ручной
распаковки программы setup.exe или путем копирования его из уже
существующего установленного варианта. Это может привести к появлению
странных ошибок, которые будут казаться совсем не связанными с неправильной установкой.


<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.79.3.orig.tar.bz2: dvdisaster-0.79.3/documentation/ru/download30.php <==
<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2010 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<h3>Установка из исходных текстов</h3>

dvdisaster использует обычный механизм: <tt>./configure; make; make install</tt>,- 
для установки из исходных текстов. Более подробно смотрите в файле <tt>INSTALL</tt> в
дистрибутиве исходных текстов.
<pre> </pre>

<a name="mac"></a>
<h3>Установка двоичных файлов для Mac OS X</h3>
В ZIP-архиве содержится пакет приложения, сделанный для Mac OS X 10.5
на процессорах x86. Распакуйте архив в нужное место и нажмите кнопку мыши на
"dvdisaster.app" для запуска программы.
dvdisaster может работать под Mac OS X 10.4 и на процессорах PowerPC;
однако в таком случае вам потребуется собрать свою собственную версию из
исходных текстов.<p>

<i>Имейте в виду, что графический интерфейс пользователя еще немного 
шероховат.</i> Набор средств для построения интерфейсов GTK+ еще находится в ранней
стадии развития для Mac OS X. Интерфейс пользователя может выглядеть неаккуратно или
замирать на небольшое время. В графическом выводе могут быть сбои.
Вы можете минимизировать эти эффекты, не трогая окно dvdisaster,
когда что-либо происходит в окне. В особенности избегайте изменения размеров окна
и сворачивания его.<p>

Во время цикла разработки версии 0.73 могут быть реализованы некоторые обходные пути
для этих эффектов; в противном случает планируется подождать улучшенной версии
GTK+.<p>

Не планируется разработка версии dvdisaster, независимой от GTK+,
поскольку это означает полное переписывание программы для Quartz.
Между прочим, аналогичные соображения относятся к версии для Windows ;-)
<pre> </pre>

<a name="win"> </a>
<h3>Установка двоичных версий для Windows</h3>

Для установки Windows-версии, запускайте на выполнение двоичный файл
(например,  <?php echo ${pkgname}?>-setup.exe) и следуйте диалогу в процессе установки. <p>

<b>Предупреждение:</b> dvdisaster НЕ устанавливается путем ручной
распаковки программы setup.exe или путем копирования его из уже
существующего установленного варианта. Это может привести к появлению
странных ошибок, которые будут казаться совсем не связанными с неправильной установкой.


<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
